Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1250)

Unified Diff: chrome/browser/extensions/external_pref_extension_loader.h

Issue 9963120: Introduces an additional extension loader that load extra extensions based on per-extension json fi… (Closed) Base URL: https://src.chromium.org/svn/trunk/src/
Patch Set: Created 8 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/extensions/external_pref_extension_loader.h
===================================================================
--- chrome/browser/extensions/external_pref_extension_loader.h (revision 133542)
+++ chrome/browser/extensions/external_pref_extension_loader.h (working copy)
@@ -29,10 +29,10 @@
ENSURE_PATH_CONTROLLED_BY_ADMIN = 1 << 0
};
- // |base_path_key| is the directory containing the external_extensions.json
- // file. Relative file paths to extension files are resolved relative
- // to this path.
- explicit ExternalPrefExtensionLoader(int base_path_key, Options options);
+ // |base_path_id| is the directory containing the external_extensions.json
+ // file or the standalone extension manifest files. Relative file paths to
+ // extension files are resolved relative to this path.
+ explicit ExternalPrefExtensionLoader(int base_path_id, Options options);
virtual const FilePath GetBaseCrxFilePath() OVERRIDE;
@@ -47,11 +47,32 @@
virtual ~ExternalPrefExtensionLoader() {}
- DictionaryValue* ReadJsonPrefsFile();
+ // Actually searches for and loads candidate standalone extension preference
+ // files in the path corresponding to |base_path_id|.
+ // Must be called on the file thread.
void LoadOnFileThread();
- int base_path_key_;
+ // Extracts the information contained in an external_extension.json file
+ // regarding which extensions to install. |prefs| will be modified to
+ // receive the extracted extension information.
+ // Must be called from the File thread.
+ void ReadExternalExtensionPrefFile(DictionaryValue * prefs);
+
+ // Extracts the information contained in standalone external extension
+ // json files (<extension id>.json) regarding what external extensions
+ // to install. |prefs| will be modified to receive the extracted extension
+ // information.
+ // Must be called from the File thread.
+ void ReadStandaloneExtensionPrefFiles(DictionaryValue * prefs);
+
+ // The resource id of the base path with the information about the json
+ // file containing which extensions to load.
+ int base_path_id_;
+
Options options_;
+
+ // The path (coresponding to |base_path_id_| containing the json files
+ // describing which extensions to load.
FilePath base_path_;
DISALLOW_COPY_AND_ASSIGN(ExternalPrefExtensionLoader);

Powered by Google App Engine
This is Rietveld 408576698